==> primevue-3.47.0.tgz: package/radiobutton/style/radiobuttonstyle.js <==
this.primevue = this.primevue || {};
this.primevue.radiobutton = this.primevue.radiobutton || {};
this.primevue.radiobutton.style = (function (BaseStyle) {
    'use strict';

    function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

    var BaseStyle__default = /*#__PURE__*/_interopDefaultLegacy(BaseStyle);

    var css = "\n@layer primevue {\n    .p-radiobutton {\n        position: relative;\n        display: inline-flex;\n        user-select: none;\n        vertical-align: bottom;\n    }\n\n    .p-radiobutton-input {\n        cursor: pointer;\n    }\n\n    .p-radiobutton-box {\n        display: flex;\n        justify-content: center;\n        align-items: center;\n    }\n\n    .p-radiobutton-icon {\n        -webkit-backface-visibility: hidden;\n        backface-visibility: hidden;\n        transform: translateZ(0) scale(.1);\n        border-radius: 50%;\n        visibility: hidden;\n    }\n\n    .p-radiobutton.p-highlight .p-radiobutton-icon {\n        transform: translateZ(0) scale(1.0, 1.0);\n        visibility: visible;\n    }\n}\n";
    var classes = {
      root: function root(_ref) {
        var instance = _ref.instance,
          props = _ref.props;
        return ['p-radiobutton p-component', {
          'p-highlight': instance.checked,
          'p-disabled': props.disabled
        }];
      },
      box: 'p-radiobutton-box',
      input: 'p-radiobutton-input',
      icon: 'p-radiobutton-icon'
    };
    var RadioButtonStyle = BaseStyle__default["default"].extend({
      name: 'radiobutton',
      css: css,
      classes: classes
    });

    return RadioButtonStyle;

})(primevue.base.style);

==> primevue-3.47.4.tgz: package/radiobutton/style/radiobuttonstyle.js <==
this.primevue = this.primevue || {};
this.primevue.radiobutton = this.primevue.radiobutton || {};
this.primevue.radiobutton.style = (function (BaseStyle) {
    'use strict';

    function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

    var BaseStyle__default = /*#__PURE__*/_interopDefaultLegacy(BaseStyle);

    var css = "\n@layer primevue {\n    .p-radiobutton {\n        position: relative;\n        display: inline-flex;\n        user-select: none;\n        vertical-align: bottom;\n    }\n\n    .p-radiobutton-input {\n        cursor: pointer;\n    }\n\n    .p-radiobutton-box {\n        display: flex;\n        justify-content: center;\n        align-items: center;\n    }\n\n    .p-radiobutton-icon {\n        -webkit-backface-visibility: hidden;\n        backface-visibility: hidden;\n        transform: translateZ(0) scale(.1);\n        border-radius: 50%;\n        visibility: hidden;\n    }\n\n    .p-radiobutton.p-highlight .p-radiobutton-icon {\n        transform: translateZ(0) scale(1.0, 1.0);\n        visibility: visible;\n    }\n}\n";
    var classes = {
      root: function root(_ref) {
        var instance = _ref.instance,
          props = _ref.props;
        return ['p-radiobutton p-component', {
          'p-highlight': instance.checked,
          'p-disabled': props.disabled,
          'p-invalid': props.invalid,
          'p-variant-filled': props.variant ? props.variant === 'filled' : instance.$primevue.config.inputStyle === 'filled'
        }];
      },
      box: 'p-radiobutton-box',
      input: 'p-radiobutton-input',
      icon: 'p-radiobutton-icon'
    };
    var RadioButtonStyle = BaseStyle__default["default"].extend({
      name: 'radiobutton',
      css: css,
      classes: classes
    });

    return RadioButtonStyle;

})(primevue.base.style);
